@@ -4,7 +4,7 @@ check for supported symbols
 '''
 
 import time
-
+from datetime import datetime
 import pandas as pd
 import requests
 from python_graphql_client import GraphqlClient
@@ -63,6 +63,14 @@ class USwapper:
         addv = ass[ass['symbol'] == symbol].index.values
         return addv[0]
 
+    def getlastupdated(self):
+        ts = int( self.client.execute( f'{{transactions(first: 1, orderBy: timestamp, orderDirection: desc ){{'
+                                       f'timestamp}}}}' )[
+                      'data']['transactions'][0]['timestamp'] )
+        value = datetime.fromtimestamp( ts )
+
+        return f'{value:%Y-%m-%d %H:%M:%S}'
+
     @staticmethod
     def getassets():
         while True:
@@ -78,8 +86,3 @@ class USwapper:
                 ass.drop( columns=['maker_fee', 'taker_fee'], inplace=True )
                 return ass
 
-
-us = USwapper()
-us.getassets()
-print( us.ethprice )
-print(us.getassets())
